@@ -687,41 +687,6 @@ def _write_value(value, args, ctx):
     ctx.formatters = formatters
 
 
-class TemplateData:
-  """A custom dictionary-like object that allows one-time definition
-  of keys, and only value fetches and changes, and key deletions,
-  thereafter.
-
-  EZT doesn't require the use of this special class -- a normal
-  dict-type data dictionary works fine.  But use of this class will
-  assist those who want the data sent to their templates to have a
-  consistent set of keys."""
-
-  def __init__(self, initial_data={}):
-    self._items = initial_data
-    
-  def __getitem__(self, key):
-    return self._items.__getitem__(key)
-
-  def __setitem__(self, key, item):
-    assert self._items.has_key(key)
-    return self._items.__setitem__(key, item)
-
-  def __delitem__(self, key):
-    return self._items.__delitem__(key)
-
-  def keys(self):
-    return self._items.keys()
-
-  def merge(self, template_data):
-    """Merge the data in TemplataData instance TEMPLATA_DATA into this
-    instance.  Avoid the temptation to use this conditionally in your
-    code -- it rather defeats the purpose of this class."""
-    
-    assert isinstance(template_data, TemplateData)
-    self._items.update(template_data._items)
-
-
 class Context:
   """A container for the execution context"""
   def __init__(self, fp):
